==> gnue-common_0.5.4.1.orig.tar.gz: gnue-common-0.5.4.1/src/datasources/drivers/interbase/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
"""
Info for this database.
"""

#
# Documentation
#
name = "Firebird/Interbase"
url = "http://www.firebirdsql.org/"
description = """
Firebird is a free relational database offering many ANSI SQL-92 features that
runs on Linux, Windows, and a variety of Unix platforms. Firebird offers
excellent concurrency, high performance, and powerful language support for
stored procedures and triggers. It has been used in production systems,
under a variety of names since 1981.

Interbase is a commercial database available from Borland.

Firebird and Interbase share a common API, which allows GNUe to use the same
drivers for both.

Firebird is a popular choice of GNUe's Windows-based developers.
"""
isfree = False  # Should be false for non-free DBMSs... we don't want to
                   # show URLs for non-free on our website

==> gnue-common_0.5.14.orig.tar.gz: gnue-common-0.5.14/src/datasources/drivers/interbase/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
"""
Info for this database.
"""

#
# Documentation
#
name = "Firebird/Interbase"
url = "http://www.firebirdsql.org/"
description = """
Firebird is a free relational database offering many ANSI SQL-92 features that
runs on GNU/Linux, Windows, and a variety of Unix platforms. Firebird offers
excellent concurrency, high performance, and powerful language support for
stored procedures and triggers. It has been used in production systems,
under a variety of names since 1981.

Interbase is a proprietary database available from Borland.

Firebird and Interbase share a common API, which allows GNUe to use the same
drivers for both.

Firebird is a popular choice of GNUe's Windows-based developers.
"""
isfree = False  # Should be false for non-free DBMSs... we don't want to
                   # show URLs for non-free on our website
